==> libgal-0.2.0.tar.gz: libgal-0.2.0/gravity/gal_stunf_test.c <==
/*  
 *  - - - - - - - - - - - - - - -  
 *   g a l _ s t u n f _ t e s t  
 *  - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_stunf routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Notes:
 *
 *     1) Tests a0 - a3 from Vallado ( page 520 )
 *
 *  References: 
 *
 *     Fundamentals of Astrodynamics and Applications
 *     by David A. Vallado, Second Section, Second Pressing
 * 
 *  Called:
 *  
 *     gal_stunf  
 *     gal_vdv  
 *  
 *  This Revision:
 *  
 *     2008 March 22 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_stunf_test.h"
#include "gal_stunf.h"
#include "gal_test.h"
 
void  
gal_stunf_test  
 (  
 ) 
 
{

  extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
  gal_vdv ( gal_stunf (  4,  0 ) *    5.4014333e-7,     0.162042999e-5, 1e-19, "gal_stunf", "a 0" ) ;  
  gal_vdv ( gal_stunf ( 50,  1 ) * 3.6207058999e-9,    1.0190578627e-9, 1e-19, "gal_stunf", "a 1" ) ;  
  gal_vdv ( gal_stunf ( 70, 61 ) * 1.0135874999e-9, 1.1139997431e-116, 1e-126, "gal_stunf", "a 2" ) ;  
  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */

==> libgal-0.3.0.tar.gz: libgal-0.3.0/gravity/gal_stunf_test.c <==
/*  
 *  - - - - - - - - - - - - - - -  
 *   g a l _ s t u n f _ t e s t  
 *  - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_stunf routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Notes:
 *
 *     1) Tests a0 - a3 from Vallado ( page 520 )
 *
 *  References: 
 *
 *     Fundamentals of Astrodynamics and Applications
 *     by David A. Vallado, Second Section, Second Pressing
 * 
 *  Called:
 *  
 *     gal_stunf  
 *     gal_vdv 
 *     gal_facexp_alloc
 *     gal_facexp_free 
 *  
 *  This Revision:
 *  
 *     2008 May 30 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_stunf_test.h"
#include "gal_stunf.h"
#include "gal_test.h"
#include "gal_facexp_alloc.h"
#include "gal_facexp_free.h"
 
void  
gal_stunf_test  
 (  
 ) 
 
{

  extern int gal_tfunc ;  

  gal_facexp_t *facexp ;
    
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  facexp = gal_facexp_alloc ( 140 ) ;
    
  gal_vdv ( gal_stunf ( facexp,  4,  0 ) *    5.4014333e-7,     0.162042999e-5,  0.0, "gal_stunf", "a 0" ) ;  
  gal_vdv ( gal_stunf ( facexp, 50,  1 ) * 3.6207058999e-9,    1.0190578627e-9,  1e-19, "gal_stunf", "a 1" ) ;  
  gal_vdv ( gal_stunf ( facexp, 70, 61 ) * 1.0135874999e-9, 1.1139997431e-116,  1e-126, "gal_stunf", "a 2" ) ;  

  gal_facexp_free ( facexp ) ;
    
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */
